pub async fn readiness_check(__arg0: State<SharedPool>) -> ResponseExpand description
Readiness check endpoint.
Returns 200 OK if the pool has capacity to handle requests, 503 Service Unavailable otherwise.
Endpoint
GET /readypub async fn readiness_check(__arg0: State<SharedPool>) -> ResponseReadiness check endpoint.
Returns 200 OK if the pool has capacity to handle requests, 503 Service Unavailable otherwise.
GET /ready