pub type SharedPool = Arc<BrowserPool>;Expand description
Type alias for shared browser pool.
This is the standard pool type used by the service functions.
Aliased Type
pub struct SharedPool { /* private fields */ }pub type SharedPool = Arc<BrowserPool>;Type alias for shared browser pool.
This is the standard pool type used by the service functions.
pub struct SharedPool { /* private fields */ }